const express = require('express');
const { upload, avatarUpload, handleMulterError } = require('../middleware/upload');
const { authenticateToken } = require('../middleware/auth');
const {
  uploadFiles,
  uploadAvatar,
  getFile,
  getAvatar,
  deleteFile,
  listFiles
} = require('../controllers/uploadController');

const router = express.Router();

router.post('/files', authenticateToken, upload.array('files', 5), uploadFiles);

router.post('/avatar', authenticateToken, avatarUpload.single('avatar'), uploadAvatar);

router.get('/files', authenticateToken, listFiles);

router.get('/files/:filename', getFile);

router.get('/avatars/:filename', getAvatar);

router.delete('/files/:filename', authenticateToken, deleteFile);

router.use(handleMulterError);

module.exports = router;